==> rfordummies_0.1.1.tar.gz: rfordummies/R/chapters-auto.R <==
#' Print examples of chapter 1 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch1()}. To run all the examples of \code{ch1()}, use \code{example(ch1)}.
#' @export
#' @rdname ch01
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch01.R
ch01 <- function(){
  text <- .readExampleFile("ch01.R")
  cat(text, sep="
")
  invisible(text)
}


#' @export
#' @aliases ch01
#' @rdname ch01
ch1 <- ch01


#' Print examples of chapter 2 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch2()}. To run all the examples of \code{ch2()}, use \code{example(ch2)}.
#' @export
#' @rdname ch02
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch02.R
ch02 <- function(){
  text <- .readExampleFile("ch02.R")
  cat(text, sep="
")
  invisible(text)
}


#' @export
#' @aliases ch02
#' @rdname ch02
ch2 <- ch02


#' Print examples of chapter 3 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch3()}. To run all the examples of \code{ch3()}, use \code{example(ch3)}.
#' @export
#' @rdname ch03
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch03.R
ch03 <- function(){
  text <- .readExampleFile("ch03.R")
  cat(text, sep="
")
  invisible(text)
}


#' @export
#' @aliases ch03
#' @rdname ch03
ch3 <- ch03


#' Print examples of chapter 4 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch4()}. To run all the examples of \code{ch4()}, use \code{example(ch4)}.
#' @export
#' @rdname ch04
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch04.R
ch04 <- function(){
  text <- .readExampleFile("ch04.R")
  cat(text, sep="
")
  invisible(text)
}


#' @export
#' @aliases ch04
#' @rdname ch04
ch4 <- ch04


#' Print examples of chapter 5 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch5()}. To run all the examples of \code{ch5()}, use \code{example(ch5)}.
#' @export
#' @rdname ch05
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch05.R
ch05 <- function(){
  text <- .readExampleFile("ch05.R")
  cat(text, sep="
")
  invisible(text)
}


#' @export
#' @aliases ch05
#' @rdname ch05
ch5 <- ch05


#' Print examples of chapter 6 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch6()}. To run all the examples of \code{ch6()}, use \code{example(ch6)}.
#' @export
#' @rdname ch06
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch06.R
ch06 <- function(){
  text <- .readExampleFile("ch06.R")
  cat(text, sep="
")
  invisible(text)
}


#' @export
#' @aliases ch06
#' @rdname ch06
ch6 <- ch06


#' Print examples of chapter 7 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch7()}. To run all the examples of \code{ch7()}, use \code{example(ch7)}.
#' @export
#' @rdname ch07
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch07.R
ch07 <- function(){
  text <- .readExampleFile("ch07.R")
  cat(text, sep="
")
  invisible(text)
}


#' @export
#' @aliases ch07
#' @rdname ch07
ch7 <- ch07


#' Print examples of chapter 8 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch8()}. To run all the examples of \code{ch8()}, use \code{example(ch8)}.
#' @export
#' @rdname ch08
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch08.R
ch08 <- function(){
  text <- .readExampleFile("ch08.R")
  cat(text, sep="
")
  invisible(text)
}


#' @export
#' @aliases ch08
#' @rdname ch08
ch8 <- ch08


#' Print examples of chapter 9 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch9()}. To run all the examples of \code{ch9()}, use \code{example(ch9)}.
#' @export
#' @rdname ch09
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch09.R
ch09 <- function(){
  text <- .readExampleFile("ch09.R")
  cat(text, sep="
")
  invisible(text)
}


#' @export
#' @aliases ch09
#' @rdname ch09
ch9 <- ch09


#' Print examples of chapter 10 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch10()}. To run all the examples of \code{ch10()}, use \code{example(ch10)}.
#' @export
#' @rdname ch10
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch10.R
ch10 <- function(){
  text <- .readExampleFile("ch10.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 11 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch11()}. To run all the examples of \code{ch11()}, use \code{example(ch11)}.
#' @export
#' @rdname ch11
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch11.R
ch11 <- function(){
  text <- .readExampleFile("ch11.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 12 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch12()}. To run all the examples of \code{ch12()}, use \code{example(ch12)}.
#' @export
#' @rdname ch12
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch12.R
ch12 <- function(){
  text <- .readExampleFile("ch12.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 13 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch13()}. To run all the examples of \code{ch13()}, use \code{example(ch13)}.
#' @export
#' @rdname ch13
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch13.R
ch13 <- function(){
  text <- .readExampleFile("ch13.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 14 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch14()}. To run all the examples of \code{ch14()}, use \code{example(ch14)}.
#' @export
#' @rdname ch14
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch14.R
ch14 <- function(){
  text <- .readExampleFile("ch14.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 15 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch15()}. To run all the examples of \code{ch15()}, use \code{example(ch15)}.
#' @export
#' @rdname ch15
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch15.R
ch15 <- function(){
  text <- .readExampleFile("ch15.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 16 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch16()}. To run all the examples of \code{ch16()}, use \code{example(ch16)}.
#' @export
#' @rdname ch16
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch16.R
ch16 <- function(){
  text <- .readExampleFile("ch16.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 17 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch17()}. To run all the examples of \code{ch17()}, use \code{example(ch17)}.
#' @export
#' @rdname ch17
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch17.R
ch17 <- function(){
  text <- .readExampleFile("ch17.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 18 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch18()}. To run all the examples of \code{ch18()}, use \code{example(ch18)}.
#' @export
#' @rdname ch18
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch18.R
ch18 <- function(){
  text <- .readExampleFile("ch18.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 19 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch19()}. To run all the examples of \code{ch19()}, use \code{example(ch19)}.
#' @export
#' @rdname ch19
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch19.R
ch19 <- function(){
  text <- .readExampleFile("ch19.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 20 of 'R for Dummies'.
#' 
#' To print a listing of all examples of a chapter, use \code{ch20()}. To run all the examples of \code{ch20()}, use \code{example(ch20)}.
#' @export
#' @rdname ch20
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example /inst/scripts/2-clean/ch20.R
ch20 <- function(){
  text <- .readExampleFile("ch20.R")
  cat(text, sep="
")
  invisible(text)
}

==> rfordummies_0.1.2.tar.gz: rfordummies/R/chapters-auto.R <==
#' Print examples of chapter 1 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch1()}. To run all the examples of \code{ch1()}, use \code{example(ch1)}.
#' @export
#' @rdname ch01
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch01.R
ch01 <- function(){
  text <- .readExampleFile("ch01.R")
  cat(text, sep="
")
  invisible(text)
}

#' @export
#' @aliases ch01
#' @rdname ch01
ch1 <- ch01

#' Print examples of chapter 2 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch2()}. To run all the examples of \code{ch2()}, use \code{example(ch2)}.
#' @export
#' @rdname ch02
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch02.R
ch02 <- function(){
  text <- .readExampleFile("ch02.R")
  cat(text, sep="
")
  invisible(text)
}

#' @export
#' @aliases ch02
#' @rdname ch02
ch2 <- ch02

#' Print examples of chapter 3 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch3()}. To run all the examples of \code{ch3()}, use \code{example(ch3)}.
#' @export
#' @rdname ch03
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch03.R
ch03 <- function(){
  text <- .readExampleFile("ch03.R")
  cat(text, sep="
")
  invisible(text)
}

#' @export
#' @aliases ch03
#' @rdname ch03
ch3 <- ch03

#' Print examples of chapter 4 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch4()}. To run all the examples of \code{ch4()}, use \code{example(ch4)}.
#' @export
#' @rdname ch04
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch04.R
ch04 <- function(){
  text <- .readExampleFile("ch04.R")
  cat(text, sep="
")
  invisible(text)
}

#' @export
#' @aliases ch04
#' @rdname ch04
ch4 <- ch04

#' Print examples of chapter 5 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch5()}. To run all the examples of \code{ch5()}, use \code{example(ch5)}.
#' @export
#' @rdname ch05
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch05.R
ch05 <- function(){
  text <- .readExampleFile("ch05.R")
  cat(text, sep="
")
  invisible(text)
}

#' @export
#' @aliases ch05
#' @rdname ch05
ch5 <- ch05

#' Print examples of chapter 6 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch6()}. To run all the examples of \code{ch6()}, use \code{example(ch6)}.
#' @export
#' @rdname ch06
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch06.R
ch06 <- function(){
  text <- .readExampleFile("ch06.R")
  cat(text, sep="
")
  invisible(text)
}

#' @export
#' @aliases ch06
#' @rdname ch06
ch6 <- ch06

#' Print examples of chapter 7 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch7()}. To run all the examples of \code{ch7()}, use \code{example(ch7)}.
#' @export
#' @rdname ch07
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch07.R
ch07 <- function(){
  text <- .readExampleFile("ch07.R")
  cat(text, sep="
")
  invisible(text)
}

#' @export
#' @aliases ch07
#' @rdname ch07
ch7 <- ch07

#' Print examples of chapter 8 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch8()}. To run all the examples of \code{ch8()}, use \code{example(ch8)}.
#' @export
#' @rdname ch08
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch08.R
ch08 <- function(){
  text <- .readExampleFile("ch08.R")
  cat(text, sep="
")
  invisible(text)
}

#' @export
#' @aliases ch08
#' @rdname ch08
ch8 <- ch08

#' Print examples of chapter 9 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch9()}. To run all the examples of \code{ch9()}, use \code{example(ch9)}.
#' @export
#' @rdname ch09
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch09.R
ch09 <- function(){
  text <- .readExampleFile("ch09.R")
  cat(text, sep="
")
  invisible(text)
}

#' @export
#' @aliases ch09
#' @rdname ch09
ch9 <- ch09

#' Print examples of chapter 10 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch10()}. To run all the examples of \code{ch10()}, use \code{example(ch10)}.
#' @export
#' @rdname ch10
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch10.R
ch10 <- function(){
  text <- .readExampleFile("ch10.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 11 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch11()}. To run all the examples of \code{ch11()}, use \code{example(ch11)}.
#' @export
#' @rdname ch11
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch11.R
ch11 <- function(){
  text <- .readExampleFile("ch11.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 12 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch12()}. To run all the examples of \code{ch12()}, use \code{example(ch12)}.
#' @export
#' @rdname ch12
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch12.R
ch12 <- function(){
  text <- .readExampleFile("ch12.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 13 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch13()}. To run all the examples of \code{ch13()}, use \code{example(ch13)}.
#' @export
#' @rdname ch13
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch13.R
ch13 <- function(){
  text <- .readExampleFile("ch13.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 14 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch14()}. To run all the examples of \code{ch14()}, use \code{example(ch14)}.
#' @export
#' @rdname ch14
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch14.R
ch14 <- function(){
  text <- .readExampleFile("ch14.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 15 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch15()}. To run all the examples of \code{ch15()}, use \code{example(ch15)}.
#' @export
#' @rdname ch15
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch15.R
ch15 <- function(){
  text <- .readExampleFile("ch15.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 16 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch16()}. To run all the examples of \code{ch16()}, use \code{example(ch16)}.
#' @export
#' @rdname ch16
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch16.R
ch16 <- function(){
  text <- .readExampleFile("ch16.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 17 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch17()}. To run all the examples of \code{ch17()}, use \code{example(ch17)}.
#' @export
#' @rdname ch17
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch17.R
ch17 <- function(){
  text <- .readExampleFile("ch17.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 18 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch18()}. To run all the examples of \code{ch18()}, use \code{example(ch18)}.
#' @export
#' @rdname ch18
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch18.R
ch18 <- function(){
  text <- .readExampleFile("ch18.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 19 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch19()}. To run all the examples of \code{ch19()}, use \code{example(ch19)}.
#' @export
#' @rdname ch19
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch19.R
ch19 <- function(){
  text <- .readExampleFile("ch19.R")
  cat(text, sep="
")
  invisible(text)
}



#' Print examples of chapter 20 of 'R for Dummies'.
#'
#' To print a listing of all examples of a chapter, use \code{ch20()}. To run all the examples of \code{ch20()}, use \code{example(ch20)}.
#' @export
#' @rdname ch20
#' @family Chapters
#' @seealso \code{\link{toc}}
#' @example inst/scripts/2-clean/ch20.R
ch20 <- function(){
  text <- .readExampleFile("ch20.R")
  cat(text, sep="
")
  invisible(text)
}
